﻿//
// Copyright (c) 2015, MindFusion LLC - Bulgaria.
//

using System;
using System.Xml;


namespace MindFusion.Scheduling.Wpf.Samples.CS.Tutorial4
{
	/// <summary>
	/// Summary description for MyApp.
	/// </summary>
	public class MyApp : Appointment
	{
		public MyApp()
		{
			_kept = true;
		}

		public override void SaveTo(XmlElement element, XmlSerializationContext context)
		{
			base.SaveTo(element, context);
			context.WriteBool(_kept, "Kept", element);
		}

		public override void LoadFrom(XmlElement element, XmlSerializationContext context)
		{
			base.LoadFrom(element, context);
			_kept = context.ReadBool("Kept", element);
		}

		protected override void CopyOccurrence(Item master)
		{
			base.CopyOccurrence(master);

			_kept = (master as MyApp).Kept;
		}

		public override object Clone()
		{
			MyApp clone = new MyApp();

			// The following code replicates the code used in
			// the Appointment's Clone method
			clone.AllDayEvent = this.AllDayEvent;
			clone.DescriptionText = this.DescriptionText;
			clone.EndTime = this.EndTime;
			clone.HeaderText = this.HeaderText;
			clone.Location = this.Location;
			clone.Locked = this.Locked;
			clone.Priority = this.Priority;
			clone.Reminder = this.Reminder;
			clone.StartTime = this.StartTime;
			clone.Tag = this.Tag;
			clone.Task = this.Task;
			clone.Visible = this.Visible;

			foreach (Resource resource in this.Resources)
				clone.Resources.Add(resource);

			foreach (Contact contact in this.Contacts)
				clone.Contacts.Add(contact);

			// Now copy the custom fields
			clone.Kept = this.Kept;

			return clone;
		}



		public bool Kept
		{
			get { return _kept; }
			set
			{
				_kept = value;

				if (Recurrence != null)
					Recurrence.MarkException(this, false);
			}
		}


		private bool _kept;
	}
}
